@@ -11,14 +11,14 @@ well with PostgreSQL views that pre-join related data into JSONB columns.
 """
 
 import logging
-from typing import Any, List, get_args, get_origin
+from typing import Any, Callable, get_args, get_origin
 
 from graphql import GraphQLResolveInfo
 
 logger = logging.getLogger(__name__)
 
 
-def create_smart_nested_field_resolver(field_name: str, field_type: Any):
+def create_smart_nested_field_resolver(field_name: str, field_type: Any) -> Callable:
     """Create a field resolver that handles nested objects based on resolve_nested setting.
 
     This resolver is only used when resolve_nested=True is set on the field type.
@@ -47,7 +47,9 @@ def create_smart_nested_field_resolver(field_name: str, field_type: Any):
         data is embedded in the parent's JSONB column.
     """
 
-    async def resolve_nested_field(parent: Any, info: GraphQLResolveInfo, **kwargs) -> Any:
+    async def resolve_nested_field(
+        parent: dict[str, Any], info: GraphQLResolveInfo, **kwargs: Any
+    ) -> Any:
         """Resolve a nested field, preferring embedded data over separate queries."""
         # First, check if the data is already present in the parent object
         value = getattr(parent, field_name, None)
@@ -111,11 +113,10 @@ def create_smart_nested_field_resolver(field_name: str, field_type: Any):
             fk_value = getattr(parent, fk_field, None)
 
             if fk_value:
+                # Attempt to query the related entity
+                db = info.context["db"]
+                table = actual_field_type.__gql_table__
                 try:
-                    # Attempt to query the related entity
-                    db = info.context["db"]
-                    table = actual_field_type.__gql_table__
-
                     # Build query parameters based on what's available in context
                     query_params = {"id": fk_value}
 
@@ -138,7 +139,7 @@ def create_smart_nested_field_resolver(field_name: str, field_type: Any):
 
                 except Exception as e:
                     logger.warning(
-                        f"Failed to query {table} for field '{field_name}': {e}. "
+                        f"Failed to query {table} for field '{field_name}': {e}. "  # type: ignore[possibly-unbound]
                         f"This may be expected if the data should be embedded."
                     )
 
@@ -148,7 +149,7 @@ def create_smart_nested_field_resolver(field_name: str, field_type: Any):
     return resolve_nested_field
 
 
-def should_use_nested_resolver(field_type: Any) -> bool:
+def should_use_nested_resolver(field_type: type) -> bool:
     """Check if a field type should use a nested resolver.
 
     This now checks the resolve_nested flag. By default (False),
@@ -182,8 +183,8 @@ def should_use_nested_resolver(field_type: Any) -> bool:
 
 
 def create_nested_array_field_resolver_with_where(
-    field_name: str, field_type: Any, field_metadata: Any = None
-):
+    field_name: str, field_type: type, field_metadata: Any = None
+) -> Callable:
     """Create a field resolver for nested arrays with comprehensive logical operator filtering.
 
     This resolver provides complete AND/OR/NOT logical operator support for filtering
@@ -222,7 +223,7 @@ def create_nested_array_field_resolver_with_where(
 
     Args:
         field_name: The name of the field being resolved
-        field_type: The type of the field (typically List[SomeType])
+        field_type: The type of the field (typically list[SomeType])
         field_metadata: FraiseQLField metadata with where configuration
 
     Returns:
@@ -231,7 +232,7 @@ def create_nested_array_field_resolver_with_where(
     """
 
     async def resolve_nested_array_with_where(
-        parent: Any, info: GraphQLResolveInfo, where: Any = None, **kwargs
+        parent: Any, info: GraphQLResolveInfo, where: Any = None, **kwargs: Any
     ) -> Any:
         """Resolve nested array field with optional where filtering."""
         # First, get the raw data using existing logic
@@ -246,7 +247,7 @@ def create_nested_array_field_resolver_with_where(
         if value is None:
             # Check if this is a list type - return empty list
             origin = get_origin(field_type)
-            if origin in (list, List):
+            if origin is list:
                 return []
             return None
 
