@@ -4,13 +4,11 @@ from .base import APQStorageBackend
 from .factory import create_apq_backend, get_backend_info
 from .memory import MemoryAPQBackend
 from .postgresql import PostgreSQLAPQBackend
-from .redis import RedisAPQBackend
 
 __all__ = [
     "APQStorageBackend",
     "MemoryAPQBackend",
     "PostgreSQLAPQBackend",
-    "RedisAPQBackend",
     "create_apq_backend",
     "get_backend_info",
 ]
