@@ -5,7 +5,7 @@ Common test configuration for FraiseQL.
 import pytest
 
 
-def pytest_configure(config):
+def pytest_configure(config) -> None:
     """Configure common test markers."""
     config.addinivalue_line("markers", "unit: Unit tests")
     config.addinivalue_line("markers", "integration: Integration tests")
