@@ -5,6 +5,6 @@ from fraiseql.db import FraiseQLRepository
 
 
 @pytest.fixture
-async def db_repo(db_pool):
+async def db_repo(db_pool) -> None:
     """FraiseQL repository fixture for enterprise tests."""
     return FraiseQLRepository(db_pool)
