@@ -1,8 +1,7 @@
-import pytest
 from pathlib import Path
 
 
-async def test_rbac_cache_setup_migration_exists():
+async def test_rbac_cache_setup_migration_exists() -> None:
     """Verify RBAC cache setup migration file exists and has correct content."""
     cache_migration_path = Path("src/fraiseql/enterprise/migrations/003_rbac_cache_setup.sql")
 
