@@ -10,15 +10,17 @@ Status: ✅ PASSING - Direct path implemented and working!
 """
 
 import pytest
-from httpx import AsyncClient, ASGITransport
+from httpx import ASGITransport, AsyncClient
 
-from fraiseql import type as fraiseql_type, query
-from fraiseql.fastapi import create_fraiseql_app
+from fraiseql import query
+from fraiseql import type as fraiseql_type
 from fraiseql.sql import create_graphql_where_input
 
 
 @pytest.mark.asyncio
-async def test_graphql_simple_query_returns_data(create_fraiseql_app_with_db, db_connection):
+async def test_graphql_simple_query_returns_data(
+    create_fraiseql_app_with_db, db_connection
+) -> None:
     """Test that simple GraphQL query returns data via direct path.
 
     ✅ Tests: GraphQL → SQL → Rust → HTTP for single object query.
@@ -52,17 +54,14 @@ async def test_graphql_simple_query_returns_data(create_fraiseql_app_with_db, db
         db = info.context["db"]
         return await db.find_one("v_user", info=info, id=id)
 
-    app = create_fraiseql_app_with_db(
-        types=[User],
-        queries=[user]
-    )
+    app = create_fraiseql_app_with_db(types=[User], queries=[user])
 
     async with AsyncClient(transport=ASGITransport(app=app), base_url="http://test") as client:
         response = await client.post(
             "/graphql",
             json={
                 "query": 'query { user(id: "11111111-1111-1111-1111-111111111111") { id firstName email } }'
-            }
+            },
         )
 
     data = response.json()
@@ -75,7 +74,7 @@ async def test_graphql_simple_query_returns_data(create_fraiseql_app_with_db, db
 
 
 @pytest.mark.asyncio
-async def test_graphql_list_query_returns_array(create_fraiseql_app_with_db, db_connection):
+async def test_graphql_list_query_returns_array(create_fraiseql_app_with_db, db_connection) -> None:
     """Test that list queries return arrays via direct path.
 
     ✅ Tests: GraphQL → SQL → Rust → HTTP for list queries.
@@ -110,15 +109,11 @@ async def test_graphql_list_query_returns_array(create_fraiseql_app_with_db, db_
         db = info.context["db"]
         return await db.find("v_user", info=info, limit=limit)
 
-    app = create_fraiseql_app_with_db(
-        types=[User],
-        queries=[users]
-    )
+    app = create_fraiseql_app_with_db(types=[User], queries=[users])
 
     async with AsyncClient(transport=ASGITransport(app=app), base_url="http://test") as client:
         response = await client.post(
-            "/graphql",
-            json={"query": "query { users(limit: 5) { id firstName } }"}
+            "/graphql", json={"query": "query { users(limit: 5) { id firstName } }"}
         )
 
     data = response.json()
@@ -129,9 +124,11 @@ async def test_graphql_list_query_returns_array(create_fraiseql_app_with_db, db_
     assert all("id" in user and "firstName" in user for user in data["data"]["users"])
 
 
-@pytest.mark.skip(reason="Schema registry singleton - only one initialization per process. Test passes individually. Run with: pytest tests/integration/graphql/test_graphql_query_execution_complete.py::test_graphql_field_selection -v")
+@pytest.mark.skip(
+    reason="Schema registry singleton - only one initialization per process. Test passes individually. Run with: pytest tests/integration/graphql/test_graphql_query_execution_complete.py::test_graphql_field_selection -v"
+)
 @pytest.mark.asyncio
-async def test_graphql_field_selection(create_fraiseql_app_with_db, db_connection):
+async def test_graphql_field_selection(create_fraiseql_app_with_db, db_connection) -> None:
     """Test that Rust field projection works correctly.
 
     ✅ Tests: Rust filters fields to only those requested in GraphQL query.
@@ -166,10 +163,7 @@ async def test_graphql_field_selection(create_fraiseql_app_with_db, db_connectio
         db = info.context["db"]
         return await db.find_one("v_user", info=info, id=id)
 
-    app = create_fraiseql_app_with_db(
-        types=[User],
-        queries=[user]
-    )
+    app = create_fraiseql_app_with_db(types=[User], queries=[user])
 
     async with AsyncClient(transport=ASGITransport(app=app), base_url="http://test") as client:
         # Request only specific fields
@@ -177,7 +171,7 @@ async def test_graphql_field_selection(create_fraiseql_app_with_db, db_connectio
             "/graphql",
             json={
                 "query": 'query { user(id: "11111111-1111-1111-1111-111111111111") { id firstName } }'
-            }
+            },
         )
 
     data = response.json()
@@ -195,7 +189,7 @@ async def test_graphql_field_selection(create_fraiseql_app_with_db, db_connectio
 
 
 @pytest.mark.asyncio
-async def test_graphql_with_where_filter(create_fraiseql_app_with_db, db_connection):
+async def test_graphql_with_where_filter(create_fraiseql_app_with_db, db_connection) -> None:
     """Test GraphQL queries with WHERE filters via direct path.
 
     ✅ Tests: WHERE filters work with dict arguments in direct path.
@@ -234,16 +228,13 @@ async def test_graphql_with_where_filter(create_fraiseql_app_with_db, db_connect
         db = info.context["db"]
         return await db.find("v_user", info=info, where=where)
 
-    app = create_fraiseql_app_with_db(
-        types=[User, UserWhereInput],
-        queries=[users]
-    )
+    app = create_fraiseql_app_with_db(types=[User, UserWhereInput], queries=[users])
 
     async with AsyncClient(transport=ASGITransport(app=app), base_url="http://test") as client:
         response = await client.post(
             "/graphql",
             json={
-                "query": '''
+                "query": """
                     query {
                         users(where: {active: {eq: true}}) {
                             id
@@ -251,8 +242,8 @@ async def test_graphql_with_where_filter(create_fraiseql_app_with_db, db_connect
                             active
                         }
                     }
-                '''
-            }
+                """
+            },
         )
 
     data = response.json()
